==> qastools_1.1.0.orig.tar.xz: qastools-v1.1.0/shared/src/wdg/pad_proxies_column.hpp <==
/// QasTools: Desktop toolset for the Linux sound system ALSA.
/// \copyright See COPYING file.

#pragma once

#include "wdg/pad_proxy.hpp"
#include <QObject>

// Forward declaration
namespace Wdg
{
class Pad_Proxies_Group;
class Pad_Proxy_Slider;
class Pad_Proxy_Switch;
class Pad_Proxy_Enum;
} // namespace Wdg

namespace Wdg
{

/// @brief Pad_Proxies_Column
///
class Pad_Proxies_Column : public QObject
{
  Q_OBJECT

  // Public methods
  public:
  // -- Construction

  Pad_Proxies_Column ( unsigned int col_idx_n = 0 );

  virtual ~Pad_Proxies_Column ();

  // -- Group

  ::Wdg::Pad_Proxies_Group *
  group () const;

  // -- Column index

  unsigned int
  column_index () const
  {
    return _column_index;
  }

  void
  set_column_index ( unsigned int idx_n );

  void
  clear_proxies ();

  // -- Slider proxy

  ::Wdg::Pad_Proxy_Slider *
  slider_proxy () const
  {
    return _proxy_slider;
  }

  void
  set_slider_proxy ( ::Wdg::Pad_Proxy_Slider * proxy_n );

  // -- Switch proxy

  ::Wdg::Pad_Proxy_Switch *
  switch_proxy () const
  {
    return _proxy_switch;
  }

  void
  set_switch_proxy ( ::Wdg::Pad_Proxy_Switch * proxy_n );

  // -- Enum proxy

  ::Wdg::Pad_Proxy_Enum *
  enum_proxy () const
  {
    return _proxy_enum;
  }

  void
  set_enum_proxy ( ::Wdg::Pad_Proxy_Enum * proxy_n );

  // -- Show value string

  void
  set_show_value_string ( bool flag_n );

  bool
  show_value_string () const
  {
    return _show_value_string;
  }

  // -- State info

  bool
  has_slider () const
  {
    return ( _proxy_slider != nullptr );
  }

  bool
  has_switch () const
  {
    return ( _proxy_switch != nullptr );
  }

  bool
  has_enum () const
  {
    return ( _proxy_enum != nullptr );
  }

  bool
  has_focus () const;

  // -- Value string

  virtual QString
  value_string () const;

  virtual QString
  value_min_string () const;

  virtual QString
  value_max_string () const;

  // -- Event handling

  bool
  event ( QEvent * event_n ) override;

  // -- Signals

  Q_SIGNAL
  void
  sig_value_string_changed ();

  // Protected methods
  protected:
  virtual void
  slider_proxy_changed ();

  virtual void
  switch_proxy_changed ();

  virtual void
  enum_proxy_changed ();

  virtual void
  show_value_string_changed ();

  // Private attributes
  private:
  unsigned int _column_index;
  ::Wdg::Pad_Proxy_Slider * _proxy_slider = nullptr;
  ::Wdg::Pad_Proxy_Switch * _proxy_switch = nullptr;
  ::Wdg::Pad_Proxy_Enum * _proxy_enum = nullptr;

  bool _has_focus = false;
  bool _show_value_string = true;
};

} // namespace Wdg

==> qastools_1.2.0.orig.tar.xz: qastools-v1.2.0/shared/src/wdg/pad_proxies_column.hpp <==
/// QasTools: Desktop toolset for the Linux sound system ALSA.
/// \copyright See COPYING file.

#pragma once

#include "wdg/pad_proxy.hpp"
#include <QObject>

// Forward declaration
namespace Wdg
{
class Pad_Proxies_Group;
class Pad_Proxy_Slider;
class Pad_Proxy_Switch;
class Pad_Proxy_Enum;
} // namespace Wdg

namespace Wdg
{

/// @brief Pad_Proxies_Column
///
class Pad_Proxies_Column : public QObject
{
  Q_OBJECT

  public:
  // -- Construction

  Pad_Proxies_Column ( unsigned int col_idx_n = 0 );

  virtual ~Pad_Proxies_Column ();

  // -- Group

  Wdg::Pad_Proxies_Group *
  group () const;

  // -- Column index

  unsigned int
  column_index () const
  {
    return _column_index;
  }

  void
  set_column_index ( unsigned int idx_n );

  void
  clear_proxies ();

  // -- Slider proxy

  Wdg::Pad_Proxy_Slider *
  slider_proxy () const
  {
    return _proxy_slider;
  }

  void
  set_slider_proxy ( Wdg::Pad_Proxy_Slider * proxy_n );

  // -- Switch proxy

  Wdg::Pad_Proxy_Switch *
  switch_proxy () const
  {
    return _proxy_switch;
  }

  void
  set_switch_proxy ( Wdg::Pad_Proxy_Switch * proxy_n );

  // -- Enum proxy

  Wdg::Pad_Proxy_Enum *
  enum_proxy () const
  {
    return _proxy_enum;
  }

  void
  set_enum_proxy ( Wdg::Pad_Proxy_Enum * proxy_n );

  // -- Show value string

  void
  set_show_value_string ( bool flag_n );

  bool
  show_value_string () const
  {
    return _show_value_string;
  }

  // -- State info

  bool
  has_slider () const
  {
    return ( _proxy_slider != nullptr );
  }

  bool
  has_switch () const
  {
    return ( _proxy_switch != nullptr );
  }

  bool
  has_enum () const
  {
    return ( _proxy_enum != nullptr );
  }

  bool
  has_focus () const;

  // -- Value string

  virtual QString
  value_string () const;

  virtual QString
  value_min_string () const;

  virtual QString
  value_max_string () const;

  // -- Event handling

  bool
  event ( QEvent * event_n ) override;

  // -- Signals

  Q_SIGNAL
  void
  sig_value_string_changed ();

  protected:
  // -- Protected methods

  virtual void
  slider_proxy_changed ();

  virtual void
  switch_proxy_changed ();

  virtual void
  enum_proxy_changed ();

  virtual void
  show_value_string_changed ();

  private:
  // -- Attributes
  unsigned int _column_index;
  Wdg::Pad_Proxy_Slider * _proxy_slider = nullptr;
  Wdg::Pad_Proxy_Switch * _proxy_switch = nullptr;
  Wdg::Pad_Proxy_Enum * _proxy_enum = nullptr;

  bool _has_focus = false;
  bool _show_value_string = true;
};

} // namespace Wdg
